#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include "settings.h"

class SettingsDialog : public QDialog
{
    Q_OBJECT
    QLabel *adress;
    QLabel *apikey;
    QLabel *port;
    QLabel *username;
    QLabel *password;
    QLineEdit *lineEditAddr;
    QLineEdit *lineEditApi;
    QLineEdit *lineEditPort;
    QLineEdit *lineEditUsername;
    QLineEdit *lineEditPassword;
    QPushButton *saveButton;
    QPushButton *testButton;

    Settings * settings;

public:
    explicit SettingsDialog(QWidget *parent = 0);

signals:

public slots:
    void saveSettings(bool);
    void testSettings(bool);
};

#endif // SETTINGSDIALOG_H
